@@ -193,7 +193,7 @@ subroutine interpolate3D(x,y,z,hh,weight,dat,itype,npart,&
     !
     !--skip particles with itype < 0
     !
-    if (itype(i) < 0) cycle over_parts
+    if (itype(i) < 0 .or. weight(i) < tiny(0.)) cycle over_parts
 
     hi = hh(i)
     if (hi <= 0.) then
@@ -490,7 +490,7 @@ subroutine interpolate3D_vec(x,y,z,hh,weight,datvec,itype,npart,&
     !
     !--skip particles with itype < 0
     !
-    if (itype(i) < 0) cycle over_parts
+    if (itype(i) < 0 .or. weight(i) < tiny(0.)) cycle over_parts
 
     hi = hh(i)
     if (hi <= 0.) cycle over_parts
