@@ -15,7 +15,7 @@
 !  a) You must cause the modified files to carry prominent notices
 !     stating that you changed the files and the date of any change.
 !
-!  Copyright (C) 2005-2017 Daniel Price. All rights reserved.
+!  Copyright (C) 2005-2022 Daniel Price. All rights reserved.
 !  Contact: daniel.price@monash.edu
 !
 !-----------------------------------------------------------------
@@ -84,21 +84,22 @@ subroutine read_data_ascii(rootname,indexstart,ipos,nstepsread)
  use params
  use settings_data,  only:ndim,ndimV,ncolumns,ncalc,iverbose,ntypes
  use mem_allocation, only:alloc
- use asciiutils,     only:get_ncolumns,get_column_labels,isdigit
+ use asciiutils,     only:get_ncolumns,get_column_labels,isdigit,readline_csv
  use system_utils,   only:ienvironment,renvironment
  use asciiread,      only:icoltype,label_orig
  use labels,         only:lenlabel,labeltype,print_types,label
+ use, intrinsic :: ieee_arithmetic
  integer, intent(in)          :: indexstart,ipos
  integer, intent(out)         :: nstepsread
  character(len=*), intent(in) :: rootname
  integer :: i,j,ierr,iunit,ncolstep,ncolenv,nerr,iheader_time,iheader_gamma
  integer :: nprint,npart_max,nstep_max,nheaderlines,nheaderenv,itype,nlabels
  integer :: noftype(maxparttypes),iverbose_was,imethod
- logical :: iexist,timeset,gammaset,got_labels
+ logical :: iexist,timeset,gammaset,got_labels,csv
  real    :: dummyreal
  real, allocatable :: dattemp(:)
  character(len=len(rootname)+4) :: dumpfile
- character(len=2048)  :: line
+ character(len=4096)  :: line
  character(len=lenlabel), dimension(size(label)) :: tmplabel
  character(len=10)  :: str,strc
  integer, parameter :: notset = -66
@@ -131,6 +132,7 @@ subroutine read_data_ascii(rootname,indexstart,ipos,nstepsread)
  icoltype = 0       ! no particle type defined by default
  got_labels = .false.
  label_orig = ''
+ csv = index(dumpfile,'.csv') > 0  ! if filename contains .csv
  !
  !--open the file and read the number of particles
  !
@@ -139,7 +141,7 @@ subroutine read_data_ascii(rootname,indexstart,ipos,nstepsread)
     print "(a)",'*** ERROR OPENING '//trim(dumpfile)//' ***'
     return
  else
-    call get_ncolumns(iunit,ncolstep,nheaderlines)
+    call get_ncolumns(iunit,ncolstep,nheaderlines,csv=csv)
     !--override header lines setting
     nheaderenv = ienvironment('ASPLASH_NHEADERLINES',-1)
     if (nheaderenv >= 0) then
@@ -165,7 +167,8 @@ subroutine read_data_ascii(rootname,indexstart,ipos,nstepsread)
        do i=1,nheaderlines
           read(iunit,"(a)",iostat=ierr) line
           !--try to match column labels from this header line, if not already matched (or dubious match)
-          call get_column_labels(trim(line),nlabels,tmplabel,method=imethod,ndesired=ncolstep)
+          call get_column_labels(trim(line),nlabels,tmplabel,&
+               method=imethod,ndesired=ncolstep,csv=csv)
           !--if we get nlabels > ncolumns, use them, but keep trying for a better match
           if ((got_labels .and. nlabels == ncolstep) .or. &
               (.not.got_labels .and. nlabels >= ncolstep  & ! only allow single-spaced labels if == ncols
@@ -283,7 +286,15 @@ subroutine read_data_ascii(rootname,indexstart,ipos,nstepsread)
        npart_max = 10*npart_max
        call alloc(npart_max,nstep_max,ncolstep+ncalc,mixedtypes=(icoltype > 0))
     endif
-    read(iunit,*,iostat=ierr) dattemp(1:ncolstep)
+    dattemp(1:ncolstep) = ieee_value(1., ieee_quiet_nan)  ! NaN if not read
+    if (csv) then
+       read(iunit,"(a)",iostat=ierr) line
+       call readline_csv(line,ncolstep,dattemp)
+    else
+       read(iunit,*,iostat=ierr) dattemp(1:ncolstep)
+    endif
+    !print*,ncolstep,nheaderlines,'line ',i,' got',dattemp(1:10)
+    !read*
     dat(i,1:ncolstep,j) = dattemp(1:ncolstep)
     if (icoltype > 0 .and. icoltype <= ncolstep .and. ierr==0 .and. (size(iamtype(:,j)) > 1)) then
        !--set particle type from type column
@@ -348,7 +359,7 @@ end subroutine read_data_ascii
 !
 !-------------------------------------------------------------------
 subroutine set_labels_ascii
- use asciiutils,      only:lcase,match_taglist,find_repeated_tags
+ use asciiutils,      only:lcase,match_taglist,find_repeated_tags,add_escape_chars
  use labels,          only:label,labeltype,ix,irho,ipmass,ih,iutherm, &
                             ipr,ivx,iBfirst,iamvec,labelvec,lenlabel, &
                             make_vector_label
@@ -432,6 +443,12 @@ subroutine set_labels_ascii
  call match_taglist((/'vx','vy','vz'/),lcase(label(1:ncolumns)),ivx,ndimV)
  call match_taglist((/'bx','by','bz'/),lcase(label(1:ncolumns)),iBfirst,ndimVtemp)
  if (ndimV==0 .and. ivx==0) call match_taglist((/'ux','uy','uz'/),lcase(label(1:ncolumns)),ivx,ndimV)
+!
+!--make labels safe for plotting
+!
+ do i=1,ncolumns
+    if (len_trim(label_orig(i)) > 0) label(i) = trim(add_escape_chars(label_orig(i)))
+ enddo
 
  got_time = .false.
  do i=1,ncolumns
@@ -535,7 +552,7 @@ subroutine set_labels_ascii
  !
  !--set labels for each particle type
  !
- labeltype(1) = 'gas'
+ labeltype(1) = ''
  UseTypeInRenderings(1) = .true.
 
 end subroutine set_labels_ascii
